from continuum.scenarios import _BaseScenario


class DataIncremental(_BaseScenario):
    """[Not Implemented Yet] Continual Loader, generating datasets for the consecutive tasks.

    Scenario: Classes and instances changes and may reappear (NIC scenario)
    """
    # TODO
